@@ -40,6 +40,13 @@ async def df_to_guoguanlv(df:pd.DataFrame):
     # result = '救援图过关率: {:.2%}'.format(resen)
     
     # 加上特殊关卡
-    resen += other_map / (all_map + other_map)
-    result = {"救援关":str('{:.2%}'.format(resen))}
+    try:
+        resen += other_map / (all_map + other_map)
+        result = {"救援关":str('{:.2%}'.format(resen))}
+    except (TypeError,KeyError):
+        result = {"救援关":"错误"}
+    except ZeroDivisionError:
+        result = {"救援关":"0.00%"}
+    except:
+        result = {"救援关":"错误"}
     return result
\ No newline at end of file
