@@ -7,7 +7,6 @@ from .config import l4_font
 """直接超的智障回复"""
 def txt_to_img(text: str, font_size=30, font_path=l4_font) -> bytes:
     text = line_break(text)
-    print(font_path)
     d_font = ImageFont.truetype(font_path, font_size)
     lines = text.count('\n')  # 计算行数
     image = Image.new("L", (LINE_CHAR_COUNT*font_size //
@@ -54,4 +53,12 @@ def line_break(line: str) -> str:
             width = 0
     if ret.endswith('\n'):
         return ret
-    return ret + '\n'
\ No newline at end of file
+    return ret + '\n'
+
+
+def mode_txt_to_img(title:str,text:str,font_size:int = 32,):
+    txt2img = Txt2Img()
+    txt2img.set_font_size(font_size)
+    pic = txt2img.draw(title, text)
+    msg = MessageSegment.image(pic)
+    return msg
\ No newline at end of file
